@@ -11,54 +11,11 @@ class ReplyApp():
     ReplyApp
     A python 3 wrapper for v1 of the ReplyApp api
     This wrapper uses getattr to build complete urls.
-    Example:
-        from replyapp import ReplyApp
-        ra = ReplyApp('Api_Key')
-
-        #ACTIONS:
-        #Mark person as replied
-        ra.actions.markasreplied(method='POST', data={'email': 'name@company.com'})
-        ra.actions.markasreplied(method='POST', data={'domain': 'company.com'})
-
-        #Push person to the campaign
-        ra.actions.pushtocampaign(method='POST', data={'campaignId': 121, 'email': 'name@company.com'})
-
-        #Add person and push to campaign
-        data = {
-            "campaignId": 121,
-            "email": "name@company.com",
-             "firstName": "James",
-             "lastName": "Smith",
-             "company": "Global Tech",
-             "city": "San Francisco",
-             "state": "CA",
-             "country": "US",
-             "title": "VP off Marketing"
-         }
-        ra.actions.addandpushtocampaign(method='POST', data=data)
-
-        #Remove person from campaign by Id
-        ra.actions.removepersonfromcampaignbyid(method='POST', data={'campaignId': 121, 'email': 'name@company.com'})
-
-        #Remove person from all campaigns
-        ra.actions.removepersonfromallcampaigns(method='POST', data={'email': 'name@company.com'})
-
-
-        #People
-        #Listing people
-        ra.people()
-
-        #Getting people from id
-        ra.people.{{ID}}()
-        #Getting people from email
-        ra.people(data={'email': 'name@company.com'})
-
-        #Saving people
-        ra.people(method='POST', data={'id': 2232, 'email': james@globaltech.com', 'firstName': 'James', 'lastName': 'Smith', 'company': 'Global Tech', 'title': 'VP of Marketing'})
-
-        #Deleting peiple
-        ra.people(method='DELETE', data={'email': 'name@company.com'})
-        ra.people.{{ID}}(method='DELETE')
+    Use dot notation to complete the URLS.
+    You can use 3 different parameters to construct the url:
+        data: Data which is passed within the body of the request
+        params: Data which is passed as parameters (?email=testing@blitzen.com) etc.
+        method: POST, GET, PUT, DELETE. If method is omitted, it defaults to GET
     '''
     def __init__(self, api_key, *args, **kwargs):
         self.api_key = api_key
@@ -73,6 +30,10 @@ class ReplyApp():
         }
 
     def __call__(self, *args, **kwargs):
+        '''
+        Call will create the url based off all attrs passed after the ReplyApp object
+        It will also take in data (Body data), params (Query parameters) and method
+        '''
         url = self.base_url + '/'.join(self._attr_path)
         for variable_name, variable_sub in kwargs.get('variable', {}).items():
             url = re.sub(variable_name, variable_sub, url)
@@ -83,10 +44,21 @@ class ReplyApp():
                             kwargs.get('params', {}))
 
     def __getattr__(self, attr, *args, **kwargs):
+        '''
+        Overwrite the getattr function in python to add each element form the dot notation
+        to the _attr_path.
+        The _attr_path is then used within __call__ to make the entire request
+        '''
         self._attr_path.append(attr)
         return self
 
     def _request(self, endpoint, data, method='GET', params = None):
+        '''
+        _request will actually make the request, and return the response json if the code is
+        successful.
+        This function will return the json from the response
+        If an error occurs, it will raise a requests raise_for_status exception
+        '''
         headers = {'Content-Type': 'application/json'}
         params['apiKey'] = self.api_key
         if type(data) == dict:
